@@ -14,12 +14,13 @@ class IdentityAuthentication(authentication.BaseAuthentication):
 
     def authenticate(self, request):
         email = request.session.get("email")
-        if not email or email not in settings.IDENTITY_WHITELIST:
+        if not email or (settings.IDENTITY_WHITELIST != 'all' and email not in settings.IDENTITY_WHITELIST):
             return None
         try:
             user = User.objects.get(email__iexact=email)
         except User.DoesNotExist:
             raise exceptions.AuthenticationFailed("No such user")
+        request.session["email"] = user.email
         return (user, None)
 
 
