@@ -80,8 +80,10 @@ def login(request):
 
     email = introspect_response.json()["username"]
     # here we can also get additional user info, GUID, etc
-    user, _ = User.objects.get_or_create(email=email, username=email)
-    request.session["username"] = email
+    user, _ = User.objects.get_or_create(
+        email__iexact=email, defaults={"username": email, "email": email}
+    )
+    request.session["email"] = email
 
     return HttpResponseRedirect(redirect_to=app_redirect_url)
 
@@ -137,10 +139,11 @@ def delete_all_unexpired_sessions_for_user(user):
     """
     logger.info(f"clearing sessions for user {user.email}, {user.id}")
     all_sessions = Session.objects.filter(expire_date__gte=now())
+
     user_sessions = [
         session.pk
         for session in all_sessions
-        if str(user.pk) == session.get_decoded().get("_auth_user_id")
+        if user.email == session.get_decoded().get("email")
     ]
     logger.debug(f"found {len(user_sessions)} user sessions")
     count, sessions_deleted = Session.objects.filter(pk__in=user_sessions).delete()
